% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/addClusters.R
\docType{methods}
\name{addClusters,ClusterExperiment,matrix-method}
\alias{addClusters,ClusterExperiment,matrix-method}
\alias{addClusters}
\alias{removeClusters}
\alias{addClusters,ClusterExperiment,ClusterExperiment-method}
\alias{addClusters,ClusterExperiment,numeric-method}
\alias{removeClusters,ClusterExperiment,character-method}
\alias{removeClusters,ClusterExperiment,numeric-method}
\alias{removeUnclustered,ClusterExperiment-method}
\alias{removeUnclustered}
\title{Functions to add/remove clusters to ClusterExperiment}
\usage{
\S4method{addClusters}{ClusterExperiment,matrix}(x, y, clusterTypes = "User")

\S4method{addClusters}{ClusterExperiment,ClusterExperiment}(x, y)

\S4method{addClusters}{ClusterExperiment,numeric}(x, y, clusterLabel = NULL,
  ...)

\S4method{removeClusters}{ClusterExperiment,character}(x, whichRemove,
  exactMatch = TRUE)

\S4method{removeClusters}{ClusterExperiment,numeric}(x, whichRemove)

\S4method{removeUnclustered}{ClusterExperiment}(x)
}
\arguments{
\item{x}{a ClusterExperiment object.}

\item{y}{additional clusters to add to x. Can be a ClusterExperiment object
or a matrix/vector of clusters.}

\item{clusterTypes}{a string describing the nature of the clustering. The
values `clusterSingle`, `clusterMany`, `mergeClusters`, `combineMany` are
reserved for the clustering coming from the package workflow and should not
be used when creating a new object with the constructor.}

\item{clusterLabel}{label(s) for the clusters being added.}

\item{...}{Passed to signature \code{ClusterExperiment,matrix}.}

\item{whichRemove}{which clusters to remove. Can be numeric or character. If
numeric, must give indices of \code{clusterMatrix(x)} to remove. If
character, should match a \code{clusterTypes} of x.}

\item{exactMatch}{logical. Whether \code{whichRemove} must exactly match a
value of \code{clusterTypes(x)}. Only relevant if whichRemove is character.}
}
\value{
A \code{\link{ClusterExperiment}} object with the added clusters.
}
\description{
These functions are used to add or remove clusters to a
\code{\link{ClusterExperiment}} object.
}
\details{
addClusters adds y to x, and is thus not symmetric in the two 
  arguments. In particular, the \code{primaryCluster}, all of the dendrogram
  information, \code{coClustering}, and \code{orderSamples} are all kept from
  the x object, even if y is a ClusterExperiment.

\code{removeClusters} removes the clusters given by
 \code{whichRemove}. If all clusters are implied, then returns a
 \code{\link[SummarizedExperiment]{SummarizedExperiment}} object. If the
 \code{primaryCluster} is one of the clusters removed, the
 \code{primaryClusterIndex} is set to 1 and the dendrogram and cooccurance
 matrix are discarded and orderSamples is set to \code{1:NCOL(x)}.

\code{removeUnclustered} removes all samples that are unclustered
  (i.e. -1 or -2 assignment) in the \code{primaryCluster} of x (so they may
  be unclustered in other clusters found in \code{clusterMatrix(x)}).
}
\examples{
data(simData)

cl1 <- clusterSingle(simData, clusterFunction="pam", subsample=FALSE,
sequential=FALSE, clusterDArgs=list(k=3))

cl2 <- clusterSingle(simData, clusterFunction="pam", subsample=FALSE,
sequential=FALSE, clusterDArgs=list(k=5))

addClusters(cl1, cl2)
}
